@@ -6,24 +6,23 @@ import uuid
 import pytest
 from airflow.exceptions import AirflowException
 from airflow.utils import timezone
-from dagster_airflow.factory import make_airflow_dag_containerized_for_handle
+from dagster_airflow.factory import make_airflow_dag_containerized_for_recon_repo
 from dagster_airflow.test_fixtures import (
     dagster_airflow_docker_operator_pipeline,
     execute_tasks_in_dag,
 )
 from dagster_airflow_tests.conftest import dagster_docker_image
-from dagster_airflow_tests.marks import nettest
+from dagster_airflow_tests.marks import nettest, requires_airflow_db
+from dagster_test.test_project import test_project_environments_path
 
-from dagster import ExecutionTargetHandle
+from dagster.core.definitions.reconstructable import ReconstructableRepository
 from dagster.core.utils import make_new_run_id
 from dagster.utils import git_repository_root, load_yaml_from_glob_list
 
 from .utils import validate_pipeline_execution, validate_skip_pipeline_execution
 
-sys.path.append(os.path.join(git_repository_root(), 'python_modules', 'libraries', 'dagster-k8s'))
-from dagster_k8s_tests.test_project import test_project_environments_path  # isort:skip
-
 
+@requires_airflow_db
 def test_fs_storage_no_explicit_base_dir(
     dagster_airflow_docker_operator_pipeline, dagster_docker_image
 ):  # pylint: disable=redefined-outer-name
@@ -31,7 +30,9 @@ def test_fs_storage_no_explicit_base_dir(
     environments_path = test_project_environments_path()
     results = dagster_airflow_docker_operator_pipeline(
         pipeline_name=pipeline_name,
-        handle=ExecutionTargetHandle.for_pipeline_module('test_pipelines.repo', pipeline_name),
+        recon_repo=ReconstructableRepository.for_module(
+            'dagster_test.test_project.test_pipelines.repo', 'define_demo_execution_repo',
+        ),
         environment_yaml=[
             os.path.join(environments_path, 'env.yaml'),
             os.path.join(environments_path, 'env_filesystem_no_explicit_base_dir.yaml'),
@@ -41,6 +42,7 @@ def test_fs_storage_no_explicit_base_dir(
     validate_pipeline_execution(results)
 
 
+@requires_airflow_db
 def test_fs_storage(
     dagster_airflow_docker_operator_pipeline, dagster_docker_image
 ):  # pylint: disable=redefined-outer-name
@@ -48,7 +50,9 @@ def test_fs_storage(
     environments_path = test_project_environments_path()
     results = dagster_airflow_docker_operator_pipeline(
         pipeline_name=pipeline_name,
-        handle=ExecutionTargetHandle.for_pipeline_module('test_pipelines.repo', pipeline_name),
+        recon_repo=ReconstructableRepository.for_module(
+            'dagster_test.test_project.test_pipelines.repo', 'define_demo_execution_repo',
+        ),
         environment_yaml=[
             os.path.join(environments_path, 'env.yaml'),
             os.path.join(environments_path, 'env_filesystem.yaml'),
@@ -59,6 +63,7 @@ def test_fs_storage(
 
 
 @nettest
+@requires_airflow_db
 def test_s3_storage(
     dagster_airflow_docker_operator_pipeline, dagster_docker_image
 ):  # pylint: disable=redefined-outer-name
@@ -66,7 +71,9 @@ def test_s3_storage(
     environments_path = test_project_environments_path()
     results = dagster_airflow_docker_operator_pipeline(
         pipeline_name=pipeline_name,
-        handle=ExecutionTargetHandle.for_pipeline_module('test_pipelines.repo', pipeline_name),
+        recon_repo=ReconstructableRepository.for_module(
+            'dagster_test.test_project.test_pipelines.repo', 'define_demo_execution_repo',
+        ),
         environment_yaml=[
             os.path.join(environments_path, 'env.yaml'),
             os.path.join(environments_path, 'env_s3.yaml'),
@@ -77,6 +84,7 @@ def test_s3_storage(
 
 
 @nettest
+@requires_airflow_db
 def test_gcs_storage(
     dagster_airflow_docker_operator_pipeline, dagster_docker_image,
 ):  # pylint: disable=redefined-outer-name
@@ -84,7 +92,9 @@ def test_gcs_storage(
     environments_path = test_project_environments_path()
     results = dagster_airflow_docker_operator_pipeline(
         pipeline_name=pipeline_name,
-        handle=ExecutionTargetHandle.for_pipeline_module('test_pipelines.repo', pipeline_name),
+        recon_repo=ReconstructableRepository.for_module(
+            'dagster_test.test_project.test_pipelines.repo', 'define_demo_execution_repo',
+        ),
         environment_yaml=[
             os.path.join(environments_path, 'env.yaml'),
             os.path.join(environments_path, 'env_gcs.yaml'),
@@ -94,6 +104,7 @@ def test_gcs_storage(
     validate_pipeline_execution(results)
 
 
+@requires_airflow_db
 def test_skip_operator(
     dagster_airflow_docker_operator_pipeline, dagster_docker_image
 ):  # pylint: disable=redefined-outer-name
@@ -101,7 +112,9 @@ def test_skip_operator(
     environments_path = test_project_environments_path()
     results = dagster_airflow_docker_operator_pipeline(
         pipeline_name=pipeline_name,
-        handle=ExecutionTargetHandle.for_pipeline_module('test_pipelines.repo', pipeline_name),
+        recon_repo=ReconstructableRepository.for_module(
+            'dagster_test.test_project.test_pipelines.repo', 'define_demo_execution_repo',
+        ),
         environment_yaml=[os.path.join(environments_path, 'env_filesystem.yaml')],
         op_kwargs={'host_tmp_dir': '/tmp'},
         image=dagster_docker_image,
@@ -109,20 +122,23 @@ def test_skip_operator(
     validate_skip_pipeline_execution(results)
 
 
+@requires_airflow_db
 def test_error_dag_containerized(dagster_docker_image):  # pylint: disable=redefined-outer-name
     pipeline_name = 'demo_error_pipeline'
-    handle = ExecutionTargetHandle.for_pipeline_module('test_pipelines.repo', pipeline_name)
+    recon_repo = ReconstructableRepository.for_module(
+        'dagster_test.test_project.test_pipelines.repo', 'define_demo_execution_repo'
+    )
     environments_path = test_project_environments_path()
     environment_yaml = [
         os.path.join(environments_path, 'env_s3.yaml'),
     ]
-    environment_dict = load_yaml_from_glob_list(environment_yaml)
+    run_config = load_yaml_from_glob_list(environment_yaml)
 
     run_id = make_new_run_id()
     execution_date = timezone.utcnow()
 
-    dag, tasks = make_airflow_dag_containerized_for_handle(
-        handle, pipeline_name, dagster_docker_image, environment_dict
+    dag, tasks = make_airflow_dag_containerized_for_recon_repo(
+        recon_repo, pipeline_name, dagster_docker_image, run_config
     )
 
     with pytest.raises(AirflowException) as exc_info:
