@@ -32,7 +32,9 @@ def test_fs_storage_no_explicit_base_dir(
     environments_path = test_project_environments_path()
     results = dagster_airflow_python_operator_pipeline(
         pipeline_name=pipeline_name,
-        recon_repo=ReconstructableRepository.for_module('test_pipelines.repo', pipeline_name),
+        recon_repo=ReconstructableRepository.for_module(
+            'dagster_test.test_project.test_pipelines.repo', pipeline_name
+        ),
         environment_yaml=[
             os.path.join(environments_path, 'env.yaml'),
             os.path.join(environments_path, 'env_filesystem_no_explicit_base_dir.yaml'),
@@ -49,7 +51,9 @@ def test_fs_storage(
     environments_path = test_project_environments_path()
     results = dagster_airflow_python_operator_pipeline(
         pipeline_name=pipeline_name,
-        recon_repo=ReconstructableRepository.for_module('test_pipelines.repo', pipeline_name),
+        recon_repo=ReconstructableRepository.for_module(
+            'dagster_test.test_project.test_pipelines.repo', pipeline_name
+        ),
         environment_yaml=[
             os.path.join(environments_path, 'env.yaml'),
             os.path.join(environments_path, 'env_filesystem.yaml'),
@@ -67,7 +71,9 @@ def test_s3_storage(
     environments_path = test_project_environments_path()
     results = dagster_airflow_python_operator_pipeline(
         pipeline_name=pipeline_name,
-        recon_repo=ReconstructableRepository.for_module('test_pipelines.repo', pipeline_name),
+        recon_repo=ReconstructableRepository.for_module(
+            'dagster_test.test_project.test_pipelines.repo', pipeline_name
+        ),
         environment_yaml=[
             os.path.join(environments_path, 'env.yaml'),
             os.path.join(environments_path, 'env_s3.yaml'),
@@ -85,7 +91,9 @@ def test_gcs_storage(
     environments_path = test_project_environments_path()
     results = dagster_airflow_python_operator_pipeline(
         pipeline_name=pipeline_name,
-        recon_repo=ReconstructableRepository.for_module('test_pipelines.repo', pipeline_name),
+        recon_repo=ReconstructableRepository.for_module(
+            'dagster_test.test_project.test_pipelines.repo', pipeline_name
+        ),
         environment_yaml=[
             os.path.join(environments_path, 'env.yaml'),
             os.path.join(environments_path, 'env_gcs.yaml'),
@@ -102,7 +110,9 @@ def test_skip_operator(
     environments_path = test_project_environments_path()
     results = dagster_airflow_python_operator_pipeline(
         pipeline_name=pipeline_name,
-        recon_repo=ReconstructableRepository.for_module('test_pipelines.repo', pipeline_name),
+        recon_repo=ReconstructableRepository.for_module(
+            'dagster_test.test_project.test_pipelines.repo', pipeline_name
+        ),
         environment_yaml=[os.path.join(environments_path, 'env_filesystem.yaml')],
     )
     validate_skip_pipeline_execution(results)
@@ -128,7 +138,9 @@ def test_rename_for_airflow():
 @requires_airflow_db
 def test_error_dag_python():  # pylint: disable=redefined-outer-name
     pipeline_name = 'demo_error_pipeline'
-    recon_repo = ReconstructableRepository.for_module('test_pipelines.repo', pipeline_name)
+    recon_repo = ReconstructableRepository.for_module(
+        'dagster_test.test_project.test_pipelines.repo', pipeline_name
+    )
     environments_path = test_project_environments_path()
     environment_yaml = [
         os.path.join(environments_path, 'env_filesystem.yaml'),
